==> kubernetes-model-flowcontrol-6.6.1-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1beta3/LimitResponseFluentImpl.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1beta3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class LimitResponseFluentImpl<A extends LimitResponseFluent<A>> extends BaseFluent<A> implements LimitResponseFluent<A>{
  public LimitResponseFluentImpl() {
  }
  public LimitResponseFluentImpl(LimitResponse instance) {
    this.withQueuing(instance.getQueuing()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private QueuingConfigurationBuilder queuing;
  private String type;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildQueuing instead.
   * @return The buildable object.
   */
  @Deprecated
  public QueuingConfiguration getQueuing() {
    return this.queuing!=null ?this.queuing.build():null;
  }
  public QueuingConfiguration buildQueuing() {
    return this.queuing!=null ?this.queuing.build():null;
  }
  public A withQueuing(QueuingConfiguration queuing) {
    _visitables.get("queuing").remove(this.queuing);
    if (queuing!=null){ this.queuing= new QueuingConfigurationBuilder(queuing); _visitables.get("queuing").add(this.queuing);} else { this.queuing = null; _visitables.get("queuing").remove(this.queuing); } return (A) this;
  }
  public Boolean hasQueuing() {
    return this.queuing != null;
  }
  public A withNewQueuing(Integer handSize,Integer queueLengthLimit,Integer queues) {
    return (A)withQueuing(new QueuingConfiguration(handSize, queueLengthLimit, queues));
  }
  public LimitResponseFluent.QueuingNested<A> withNewQueuing() {
    return new LimitResponseFluentImpl.QueuingNestedImpl();
  }
  public LimitResponseFluent.QueuingNested<A> withNewQueuingLike(QueuingConfiguration item) {
    return new LimitResponseFluentImpl.QueuingNestedImpl(item);
  }
  public LimitResponseFluent.QueuingNested<A> editQueuing() {
    return withNewQueuingLike(getQueuing());
  }
  public LimitResponseFluent.QueuingNested<A> editOrNewQueuing() {
    return withNewQueuingLike(getQueuing() != null ? getQueuing(): new QueuingConfigurationBuilder().build());
  }
  public LimitResponseFluent.QueuingNested<A> editOrNewQueuingLike(QueuingConfiguration item) {
    return withNewQueuingLike(getQueuing() != null ? getQueuing(): item);
  }
  public String getType() {
    return this.type;
  }
  public A withType(String type) {
    this.type=type; return (A) this;
  }
  public Boolean hasType() {
    return this.type != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    LimitResponseFluentImpl that = (LimitResponseFluentImpl) o;
    if (queuing != null ? !queuing.equals(that.queuing) :that.queuing != null) return false;
    if (type != null ? !type.equals(that.type) :that.type != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(queuing,  type,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (queuing != null) { sb.append("queuing:"); sb.append(queuing + ","); }
    if (type != null) { sb.append("type:"); sb.append(type + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class QueuingNestedImpl<N> extends QueuingConfigurationFluentImpl<LimitResponseFluent.QueuingNested<N>> implements LimitResponseFluent.QueuingNested<N>,Nested<N>{
    QueuingNestedImpl(QueuingConfiguration item) {
      this.builder = new QueuingConfigurationBuilder(this, item);
    }
    QueuingNestedImpl() {
      this.builder = new QueuingConfigurationBuilder(this);
    }
    QueuingConfigurationBuilder builder;
    public N and() {
      return (N) LimitResponseFluentImpl.this.withQueuing(builder.build());
    }
    public N endQueuing() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-flowcontrol-6.7.1-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1beta3/LimitResponseFluentImpl.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1beta3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class LimitResponseFluentImpl<A extends LimitResponseFluent<A>> extends BaseFluent<A> implements LimitResponseFluent<A>{
  public LimitResponseFluentImpl() {
  }
  public LimitResponseFluentImpl(LimitResponse instance) {
    if (instance != null) {
      this.withQueuing(instance.getQueuing());
      this.withType(instance.getType());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private QueuingConfigurationBuilder queuing;
  private String type;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildQueuing instead.
   * @return The buildable object.
   */
  @Deprecated
  public QueuingConfiguration getQueuing() {
    return this.queuing!=null ?this.queuing.build():null;
  }
  public QueuingConfiguration buildQueuing() {
    return this.queuing!=null ?this.queuing.build():null;
  }
  public A withQueuing(QueuingConfiguration queuing) {
    _visitables.get("queuing").remove(this.queuing);
    if (queuing!=null){ this.queuing= new QueuingConfigurationBuilder(queuing); _visitables.get("queuing").add(this.queuing);} else { this.queuing = null; _visitables.get("queuing").remove(this.queuing); } return (A) this;
  }
  public Boolean hasQueuing() {
    return this.queuing != null;
  }
  public A withNewQueuing(Integer handSize,Integer queueLengthLimit,Integer queues) {
    return (A)withQueuing(new QueuingConfiguration(handSize, queueLengthLimit, queues));
  }
  public LimitResponseFluentImpl.QueuingNested<A> withNewQueuing() {
    return new LimitResponseFluentImpl.QueuingNestedImpl();
  }
  public LimitResponseFluentImpl.QueuingNested<A> withNewQueuingLike(QueuingConfiguration item) {
    return new LimitResponseFluentImpl.QueuingNestedImpl(item);
  }
  public LimitResponseFluentImpl.QueuingNested<A> editQueuing() {
    return withNewQueuingLike(getQueuing());
  }
  public LimitResponseFluentImpl.QueuingNested<A> editOrNewQueuing() {
    return withNewQueuingLike(getQueuing() != null ? getQueuing(): new QueuingConfigurationBuilder().build());
  }
  public LimitResponseFluentImpl.QueuingNested<A> editOrNewQueuingLike(QueuingConfiguration item) {
    return withNewQueuingLike(getQueuing() != null ? getQueuing(): item);
  }
  public String getType() {
    return this.type;
  }
  public A withType(String type) {
    this.type=type; return (A) this;
  }
  public Boolean hasType() {
    return this.type != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    LimitResponseFluentImpl that = (LimitResponseFluentImpl) o;
    if (!java.util.Objects.equals(queuing, that.queuing)) return false;

    if (!java.util.Objects.equals(type, that.type)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(queuing,  type,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (queuing != null) { sb.append("queuing:"); sb.append(queuing + ","); }
    if (type != null) { sb.append("type:"); sb.append(type + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class QueuingNestedImpl<N> extends QueuingConfigurationFluentImpl<LimitResponseFluentImpl.QueuingNested<N>> implements LimitResponseFluentImpl.QueuingNested<N>,Nested<N>{
    QueuingNestedImpl(QueuingConfiguration item) {
      this.builder = new QueuingConfigurationBuilder(this, item);
    }
    QueuingNestedImpl() {
      this.builder = new QueuingConfigurationBuilder(this);
    }
    QueuingConfigurationBuilder builder;
    public N and() {
      return (N) LimitResponseFluentImpl.this.withQueuing(builder.build());
    }
    public N endQueuing() {
      return and();
    }
    
  }
  
}
